@@ -1,6 +1,6 @@
 /*save_wd example
-Copyright (C) 2008\
- Ineiev<ineiev@users.sourceforge.net>, super V 93
+Copyright (C) 2008,2009\
+ Ineiev<ineiev@users.berlios.de>, super V 93
 This program is a part of the stribog host software section
 
 This program is free software; you can redistribute it and/or modify
@@ -15,8 +15,13 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <http://www.gnu.org/licenses/>.*/
+#if HAVE_CONFIG_H
+# include<config.h>
+#endif
 #include<stdio.h>
-#include<unistd.h>
+#if HAVE_UNISTD_H
+# include<unistd.h>
+#endif
 #include"save_wd.h"
 int main(void)
 {const char file_name[]="test.txt";FILE*f=fopen(file_name,"w");
