@@ -1,5 +1,5 @@
 /*snprintf with errors output to stderr
-Copyright (C) 2006, 2007, 2008\
+Copyright (C) 2006, 2007, 2008, 2009\
  Ineiev<ineiev@users.sourceforge.net>, super V 93
 This program is a part of the stribog host software section
 
@@ -19,6 +19,12 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.*/
 #include"snprintf_checked.h"
 #include<stribog_error.h>
 #include<stdio.h>
+#if !HAVE_VSNPRINTF
+/* this should serve rather ancient cases; on the other hand,
+ * even some early snprintf() implementations
+ * were not more secure than sprintf() */
+# define vsnprintf(s,size,fmt,ap) vsprintf(s,fmt,ap)
+#endif
 int 
 snprintf_checked(const char*file,int line,
  char*s,unsigned size,const char*fmt,...)
